@@ -2,7 +2,7 @@ package SQL::Maker;
 use strict;
 use warnings;
 use 5.008001;
-our $VERSION = '1.13';
+our $VERSION = '1.14';
 use Class::Accessor::Lite 0.05 (
     ro => [qw/quote_char name_sep new_line driver select_class/],
 );
@@ -122,11 +122,19 @@ sub _quote {
 }
 
 sub delete {
-    my ($self, $table, $where) = @_;
+    my ($self, $table, $where, $opt) = @_;
 
     my $w = $self->_make_where_clause($where);
     my $quoted_table = $self->_quote($table);
-    my $sql = "DELETE FROM $quoted_table" . $w->[0];
+    my $sql = "DELETE FROM $quoted_table";
+    if ($opt->{using}) {
+        # $bulder->delete('foo', \%where, { using => 'bar' });
+        # $bulder->delete('foo', \%where, { using => ['bar', 'qux'] });
+        my $tables = ref($opt->{using}) eq 'ARRAY' ? $opt->{using} : [$opt->{using}];
+        my $using = join(', ', map { $self->_quote($_) } @$tables);
+        $sql .= " USING " . $using;
+    }
+    $sql .= $w->[0];
     return ($sql, @{$w->[1]});
 }
 
@@ -324,7 +332,7 @@ SQL::Maker - Yet another SQL builder
     ($sql, @binds) = $builder->insert($table, \%values, \%opt);
 
     # DELETE
-    ($sql, @binds) = $builder->delete($table, \%where);
+    ($sql, @binds) = $builder->delete($table, \%where, \%opt);
 
     # UPDATE
     ($sql, @binds) = $builder->update($table, \%set, \%where);
@@ -338,7 +346,7 @@ SQL::Maker is yet another SQL builder class. It is based on L<DBIx::Skinny>'s SQ
 
 =over 4
 
-=item my $builder = SQL::Maker->new(%args);
+=item C<< my $builder = SQL::Maker->new(%args); >>
 
 Create new instance of SQL::Maker.
 
@@ -370,104 +378,104 @@ Default: '\n'
 
 =back
 
-=item my $select = $builder->new_select(%args|\%args);
+=item C<< my $select = $builder->new_select(%args|\%args); >>
 
-Create new instance of L<SQL::Maker::Select> from the settings from B<$builder>.
+Create new instance of L<SQL::Maker::Select> using the settings from B<$builder>.
 
-This method returns instance of L<SQL::Maker::Select>.
+This method returns an instance of L<SQL::Maker::Select>.
 
-=item my ($sql, @binds) = $builder->select($table|\@tables, \@fields, \%where|\@where|$where, \%opt);
+=item C<< my ($sql, @binds) = $builder->select($table|\@tables, \@fields, \%where|\@where|$where, \%opt); >>
 
     my ($sql, @binds) = $builder->select('user', ['*'], {name => 'john'}, {order_by => 'user_id DESC'});
     # =>
     #   SELECT * FROM `user` WHERE (`name` = ?) ORDER BY user_id DESC
     #   ['john']
 
-This method returns SQL string and bind variables for SELECT statement.
+This method returns the SQL string and bind variables for a SELECT statement.
 
 =over 4
 
-=item $table
+=item C<< $table >>
 
-=item \@tables
+=item C<< \@tables >>
 
-Table name for B<FROM> clause in scalar or arrayref. You can specify the instance of B<SQL::Maker::Select> for sub-query.
+Table name for the B<FROM> clause as scalar or arrayref. You can specify the instance of B<SQL::Maker::Select> for a sub-query.
 
 If you are using C<< $opt->{joins} >> this should be I<< undef >> since it's passed via the first join.
 
-=item \@fields
+=item C<< \@fields >>
 
 This is a list for retrieving fields from database.
 
-Each element of the C<@field> is a scalar or a scalar ref of the column name normally.
-If you want to specify alias of the field, you can use ArrayRef containing the pair of column
-and alias name (e.g. C<< ['foo.id' => 'foo_id'] >>).
+Each element of the C<@fields> is normally a scalar or a scalar ref containing the column name.
+If you want to specify an alias of the field, you can use an arrayref containing a pair
+of column and alias names (e.g. C<< ['foo.id' => 'foo_id'] >>).
 
-=item \%where
+=item C<< \%where >>
 
-=item \@where
+=item C<< \@where >>
 
-=item $where
+=item C<< $where >>
 
 where clause from hashref or arrayref via L<SQL::Maker::Condition>, or L<SQL::Maker::Condition> object.
 
-=item \%opt
+=item C<< \%opt >>
 
-This is a options for SELECT statement
+These are the options for the SELECT statement
 
 =over 4
 
-=item $opt->{prefix}
+=item C<< $opt->{prefix} >>
 
-This is a prefix for SELECT statement.
+This is a prefix for the SELECT statement.
 
 For example, you can provide the 'SELECT SQL_CALC_FOUND_ROWS '. It's useful for MySQL.
 
 Default Value: 'SELECT '
 
-=item $opt->{limit}
+=item C<< $opt->{limit} >>
 
-This option makes 'LIMIT $n' clause.
+This option adds a 'LIMIT $n' clause.
 
-=item $opt->{offset}
+=item C<< $opt->{offset} >>
 
-This option makes 'OFFSET $n' clause.
+This option adds an 'OFFSET $n' clause.
 
-=item $opt->{order_by}
+=item C<< $opt->{order_by} >>
 
-This option makes B<ORDER BY> clause
+This option adds an B<ORDER BY> clause
 
-You can write it as the following forms:
+You can write it in any of the following forms:
 
     $builder->select(..., {order_by => 'foo DESC, bar ASC'});
     $builder->select(..., {order_by => ['foo DESC', 'bar ASC']});
     $builder->select(..., {order_by => {foo => 'DESC'}});
     $builder->select(..., {order_by => [{foo => 'DESC'}, {bar => 'ASC'}]});
 
-=item $opt->{group_by}
+=item C<< $opt->{group_by} >>
 
-This option makes B<GROUP BY> clause
+This option adds a B<GROUP BY> clause
 
-You can write it as the following forms:
+You can write it in any of the following forms:
 
     $builder->select(..., {group_by => 'foo DESC, bar ASC'});
     $builder->select(..., {group_by => ['foo DESC', 'bar ASC']});
     $builder->select(..., {group_by => {foo => 'DESC'}});
     $builder->select(..., {group_by => [{foo => 'DESC'}, {bar => 'ASC'}]});
 
-=item $opt->{having}
+=item C<< $opt->{having} >>
 
-This option makes HAVING clause
+This option adds a HAVING clause
 
-=item $opt->{for_update}
+=item C<< $opt->{for_update} >>
 
-This option makes 'FOR UPDATE" clause.
+This option adds a 'FOR UPDATE" clause.
 
-=item $opt->{joins}
+=item C<< $opt->{joins} >>
 
-This option makes 'JOIN' via L<SQL::Maker::Select>.
+This option adds a 'JOIN' via L<SQL::Maker::Select>.
 
-You can write it as the following:
+You can write it as follows:
 
     $builder->select(undef, ..., {joins => [[user => {table => 'group', condition => 'user.gid = group.gid'}], ...]});
 
@@ -475,32 +483,32 @@ You can write it as the following:
 
 =back
 
-=item my ($sql, @binds) = $builder->insert($table, \%values|\@values, \%opt);
+=item C<< my ($sql, @binds) = $builder->insert($table, \%values|\@values, \%opt); >>
 
     my ($sql, @binds) = $builder->insert(user => {name => 'john'});
     # =>
     #    INSERT INTO `user` (`name`) VALUES (?)
     #    ['john']
 
-Generate INSERT query.
+Generate an INSERT query.
 
 =over 4
 
-=item $table
+=item C<< $table >>
 
 Table name in scalar.
 
-=item \%values
+=item C<< \%values >>
 
 These are the values for the INSERT statement.
 
-=item \%opt
+=item C<< \%opt >>
 
 These are the options for the INSERT statement
 
 =over 4
 
-=item $opt->{prefix}
+=item C<< $opt->{prefix} >>
 
 This is a prefix for the INSERT statement.
 
@@ -512,34 +520,52 @@ Default Value: 'INSERT INTO'
 
 =back
 
-=item my ($sql, @binds) = $builder->delete($table, \%where|\@where|$where);
+=item C<< my ($sql, @binds) = $builder->delete($table, \%where|\@where|$where, \%opt); >>
 
     my ($sql, @binds) = $builder->delete($table, \%where);
     # =>
     #    DELETE FROM `user` WHERE (`name` = ?)
     #    ['john']
 
-Generate DELETE query.
+Generate a DELETE query.
 
 =over 4
 
-=item $table
+=item C<< $table >>
 
 Table name in scalar.
 
-=item \%where
+=item C<< \%where >>
 
-=item \@where
+=item C<< \@where >>
 
-=item $where
+=item C<< $where >>
 
 where clause from hashref or arrayref via L<SQL::Maker::Condition>, or L<SQL::Maker::Condition> object.
 
+=item C<< \%opt >>
+
+These are the options for the DELETE statement
+
+=over 4
+
+=item C<< $opt->{using} >>
+
+This option adds a USING clause. It takes a scalar or an arrayref of table names as argument:
+
+    my ($sql, $binds) = $bulder->delete($table, \%where, { using => 'group' });
+    # =>
+    #    DELETE FROM `user` USING `group` WHERE (`group`.`name` = ?)
+    #    ['doe']
+    $bulder->delete(..., { using => ['bar', 'qux'] });
+
 =back
 
-=item my ($sql, @binds) = $builder->update($table, \%set|@set, \%where|\@where|$where);
+=back
 
-Generate UPDATE query.
+=item C<< my ($sql, @binds) = $builder->update($table, \%set|@set, \%where|\@where|$where); >>
+
+Generate a UPDATE query.
 
     my ($sql, @binds) = $builder->update('user', ['name' => 'john', email => 'john@example.com'], {user_id => 3});
     # =>
@@ -562,27 +588,27 @@ Setting values.
 
 =item $where
 
-where clause from hashref or arrayref via L<SQL::Maker::Condition>, or L<SQL::Maker::Condition> object.
+where clause from a hashref or arrayref via L<SQL::Maker::Condition>, or L<SQL::Maker::Condition> object.
 
 =back
 
-=item $builder->new_condition()
+=item C<< $builder->new_condition() >>
 
 Create new L<SQL::Maker::Condition> object from C< $builder > settings.
 
-=item my ($sql, @binds) = $builder->where(\%where)
+=item C<< my ($sql, @binds) = $builder->where(\%where) >>
 
-=item my ($sql, @binds) = $builder->where(\@where)
+=item C<< my ($sql, @binds) = $builder->where(\@where) >>
 
-=item my ($sql, @binds) = $builder->where(\@where)
+=item C<< my ($sql, @binds) = $builder->where(\@where) >>
 
-Where clause from hashref or arrayref via L<SQL::Maker::Condition>, or L<SQL::Maker::Condition> object.
+Where clause from a hashref or arrayref via L<SQL::Maker::Condition>, or L<SQL::Maker::Condition> object.
 
 =back
 
 =head1 PLUGINS
 
-SQL::Maker supports plugin system. Write the code like following.
+SQL::Maker features a plugin system. Write the code as follows:
 
     package My::SQL::Maker;
     use parent qw/SQL::Maker/;
@@ -592,7 +618,7 @@ SQL::Maker supports plugin system. Write the code like following.
 
 =over 4
 
-=item Why don't you use  SQL::Abstract?
+=item Why don't you use SQL::Abstract?
 
 I need a more extensible one.
 
